Documentation
¶
Index ¶
- func GatherProjects(c *catalog.Catalog) error
- func GuessProjectURLFromLinks(links []Link) (string, bool)
- func LookupCategoryID(name string, categories []Category) (int, bool)
- func ProjectNameFromTopicTitle(title string) string
- func TopicHasTag(t *Topic, tag string) bool
- type Category
- type Client
- type CreatedBy
- type Details
- type Link
- type Topic
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GatherProjects ¶
GatherProjects collects up project information from the Library topic on lines
func GuessProjectURLFromLinks ¶
GuessProjectURLFromLinks attempts to find a URL for the project among the links posted in the topic
func ProjectNameFromTopicTitle ¶
ProjectNameFromTopicTitle attempts to determine the project name from topic title
func TopicHasTag ¶
Types ¶
type Category ¶
Category captures a subset of the properties of a Discourse category
func GetCategories ¶
type Client ¶
type Client struct {
Endpoint string
// contains filtered or unexported fields
}
Client struct to represent a connection to the lines Discourse API
type Topic ¶
type Topic struct {
ID int `json:"id"`
Title string `json:"title"`
FancyTitle string `json:"fancy_title"`
PostsCount int `json:"posts_count"`
CategoryID int `json:"category_id"`
Tags []string `json:"tags"`
IsVisible bool `json:"visible"`
IsArchived bool `json:"archived"`
}
Topic represents a Topic resource from the Discourse API
Click to show internal directories.
Click to hide internal directories.